#ifndef LIBAICONNECT_HELP_H
#define LIBAICONNECT_HELP_H

#include <iostream>

class Help {

public:
    static void showHelp(const std::string& option);

};

#endif //LIBAICONNECT_HELP_H